{{/* vim: set filetype=mustache: */}}
{{/*
Expand the name of the chart.
*/}}
{{- define "scaaas.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "scaaas.fullname" -}}
{{- if .Values.fullnameOverride -}}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- $name := default .Chart.Name .Values.nameOverride -}}
{{- if contains $name .Release.Name -}}
{{- .Release.Name | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" -}}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
### NOT CONFIGURABLE
### Environs listed below are NOT CONFIGURABLE
# NOTE: if you change .Values.environs for these, they will be duplicated and may cause unwanted behavior
### END NOT CONFIGURABLE
*/}}
{{- define "scaaas.defaultNonConfigurableEnvirons" -}}
MANAGER_HOST: {{ .Release.Name }}-scaaas-manager
SCANNER_HOST: {{ .Release.Name }}-scaaas-scanner
PRODUCT_NAME: SCA_AS_A_SERVICE
VERSION: {{ .Values.imageTag }}
RABBIT_MQ_HOST: {{ .Release.Name }}-scaaas-rabbitmq
{{- if eq .Values.isKubernetes true }}
ORCHESTRATION_TYPE: KUBERNETES
{{- else }}
ORCHESTRATION_TYPE: OPENSHIFT
{{- end }}
{{- end -}}

{{- define "scaaas.environs" }}
{{- range $key, $value := .Values.environs }}
{{ $key }}: {{ $value | quote }}
{{- end }}
{{- end }}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "scaaas.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Common labels
*/}}
{{- define "scaaas.labels" -}}
helm.sh/chart: {{ include "scaaas.chart" . }}
{{ include "scaaas.selectorLabels" . }}
{{- end -}}

{{/*
Selector labels
*/}}
{{- define "scaaas.selectorLabels" -}}
app: scaaas
name: {{ .Release.Name }}
version: {{ .Values.imageTag }}
{{- end -}}

{{/*
Common labels without version
*/}}
{{- define "scaaas.labelsWithoutVersion" -}}
helm.sh/chart: {{ include "scaaas.chart" . }}
{{ include "scaaas.selectorLabelsWithoutVersion" . }}
{{- end -}}

{{/*
Selector labels without version
*/}}
{{- define "scaaas.selectorLabelsWithoutVersion" -}}
app: scaaas
name: {{ .Release.Name }}
{{- end -}}

{{/*
Security Context if Kubernetes
*/}}
{{- define "scaaas.podSecurityContext" -}}
{{- if .Values.isKubernetes -}}
securityContext:
  fsGroup: 0
{{- end -}}
{{- end -}}

{{/*
Image pull secrets to pull the image
*/}}
{{- define "scaaas.imagePullSecrets" }}
{{- if .Values.imagePullSecrets -}}
imagePullSecrets:
{{- range .Values.imagePullSecrets }}
  - name: {{ . }}
{{- end }}
{{- end }}
{{- end }}

{{/*
Enable IPV6
*/}}
{{- define "enableIPV6" -}}
{{- if .Values.enableIPV6 -}}
IPV4_ONLY: "0"
{{- else -}}
IPV4_ONLY: "1"
{{- end -}}
{{- end -}}


{{/*
# Override imagePullPolicy.  Caller should pass in the <servicename>.imagePullPolicy scope.
# Example: --set scanner.imagePullPolicy=Never
*/}}
{{- define "customImagePullPolicy" -}}
{{- if .imagePullPolicy -}}
imagePullPolicy: {{ .imagePullPolicy }}
{{- else -}}
imagePullPolicy: {{ .globalImagePullPolicy }}
{{- end -}}
{{- end -}}

{{/*
Blackduck authentication
*/}}
{{- define "blackduck.authentication" -}}
{{- if .Values.secrets.blackduck.token -}}
- name: BLACKDUCK_SCAAAS_BLACKDUCK_TOKEN
  valueFrom:
    {{- with .Values.secrets.blackduck.token }}
    secretKeyRef:
      {{- toYaml . | nindent 6 -}}
    {{- end -}}
{{- end -}}
{{- end -}}

{{/*
Detect environment
*/}}
{{- define "scaaas.detect.environment" -}}
- name: DETECT_LATEST_RELEASE_VERSION
  value: {{ .Values.scanner.detectContext.latestReleaseVersion | default .Values.detectLatestVersionDefault | quote }}
{{- if .Values.scanner.detectContext.downloadSource }}
- name: DETECT_SOURCE
  value: {{ .Values.scanner.detectContext.downloadSource | quote }}
{{- end -}}
{{- if .Values.scanner.detectContext.downloadOptions }}
- name: DETECT_CURL_OPTS
  value: {{ .Values.scanner.detectContext.downloadOptions | quote }}
{{- end -}}
{{- if .Values.scanner.detectContext.detectJarDownloadDir }}
- name: DETECT_JAR_DOWNLOAD_DIR
  value: {{ .Values.scanner.detectContext.detectJarDownloadDir | quote }}
{{- end -}}

{{- end -}}
